@@ -30,7 +30,6 @@
 #include <kcolorscheme.h>
 #include <kconfiggroup.h>
 #include <kiconloader.h>
-#include <ksharedconfig.h>
 
 #include <config-platformtheme.h>
 #ifdef UNIT_TEST
@@ -38,7 +37,11 @@
 #define HAVE_X11 0
 #endif
 #if HAVE_X11
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
 #include <X11/Xcursor/Xcursor.h>
 #endif
 
@@ -67,7 +70,7 @@ static inline bool checkUsePortalSupport()
     return !QStandardPaths::locate(QStandardPaths::RuntimeLocation, QStringLiteral("flatpak-info")).isEmpty() || qEnvironmentVariableIsSet("SNAP");
 }
 
-KHintsSettings::KHintsSettings(KSharedConfig::Ptr kdeglobals)
+KHintsSettings::KHintsSettings(const KSharedConfig::Ptr &kdeglobals)
     : QObject(nullptr)
     , mKdeGlobals(kdeglobals)
     , mUsePortal(checkUsePortalSupport())
